@extends('themes.base.layout')
@section('title', trans('admin.edit_storage', ['storage_name' => $storage->name]))

@section('breadcrumb')
    <div class="breadcrumb">
        <div class="container">
            <ol class="breadcrumb">
                <li><a href="{{ route('home') }}">@lang('navigation.breadcrumb.home')</a></li>
                <li><a href="{{ route('admin') }}">@lang('navigation.breadcrumb.admin')</a></li>
                <li><a href="{{ route('storage.index') }}">@lang('navigation.breadcrumb.storage')</a></li>
                <li class="active">@lang('navigation.breadcrumb.edit_storage')</li>
            </ol>
        </div>
    </div>
@endsection

@section('content')
    <div class="container">
        <div class="row">
            <div class="col-xs-12">
                <h1>@yield('title')</h1>
                <p>@lang('admin.edit_storage_intro', ['storage_name' => $storage->name])</p>
                <hr/>

                @if (count($errors) > 0)
                    <div class="alert alert-danger">
                        <ul>
                            @foreach ($errors->all() as $formError)
                                <li>{{ $formError }}</li>
                            @endforeach
                        </ul>
                    </div>
                @endif

                {!! Form::model($storage, ['route' => ['storage.update', $storage->id], 'method' => 'PUT']) !!}
                <div class="form-group">
                    {!! Form::label('name', trans('forms.name_label'), ['class' => 'control-label']) !!}
                    {!! Form::text('name', old('name'), ['class' => 'form-control']) !!}
                </div>

                <div class="checkbox">
                    <label>
                        <input type="checkbox" name="is_default"@if ($storage->is_default) checked="checked"@endif>
                        <strong>@lang('forms.default_storage_label')</strong>
                    </label>
                </div>

                <div class="form-actions">
                    <a href="{{ route('storage.index') }}" class="btn btn-default">@lang('forms.cancel_action')</a>
                    {!! Form::submit(trans('forms.save_action'), ['class' => 'btn btn-success']) !!}
                </div>
                {!! Form::close() !!}
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script type="text/javascript">
    var viewModel = new StorageLocationsViewModel();
    ko.applyBindings(viewModel);
</script>
@endpush